package Test::Effects::Module2;

use warnings;
use strict;
use autodie;
use 5.010;

our $VERSION = '0.000001';


# Module implementation here


1; # Magic true value required at end of module
__END__

=head1 NAME

Test::Effects::Module2 - Dummy module to test WITHOUT feature
